# NMSLIB-viz

[![HitCount](http://hits.dwyl.io/AlbertSuarez/nmslib-viz.svg)](http://hits.dwyl.io/AlbertSuarez/nmslib-viz)
[![PyPI version](https://badge.fury.io/py/nmslib-viz.svg)](https://pypi.org/project/nmslib-viz/)
![Python application](https://github.com/AlbertSuarez/searchly/workflows/Python%20application/badge.svg)
![Python package](https://github.com/AlbertSuarez/nmslib-viz/workflows/Python%20package/badge.svg)
[![GitHub stars](https://img.shields.io/github/stars/AlbertSuarez/nmslib-viz.svg)](https://GitHub.com/AlbertSuarez/nmslib-viz/stargazers/)
[![GitHub forks](https://img.shields.io/github/forks/AlbertSuarez/nmslib-viz.svg)](https://GitHub.com/AlbertSuarez/nmslib-viz/network/)
[![GitHub contributors](https://img.shields.io/github/contributors/AlbertSuarez/nmslib-viz.svg)](https://GitHub.com/AlbertSuarez/nmslib-viz/graphs/contributors/)

📊 NMSLIB visualization tool

> *WORK IN PROGRESS PROJECT*

## Installation

Install client via pip. Ideally, `nmslib-viz` is well supported for Python >= 3.7.

```bash
pip install nmslib-viz
```

## Usage

Just run it like this:

```bash
nmslib-viz
```

## Contributing

Suggestions, improvements, and enhancements are always welcome! If you have any issues, please do raise one in the Issues section. If you have an improvement, do file an issue to discuss the suggestion before creating a PR.

All ideas – no matter how outrageous – welcome!

## Authors

- [Albert Suàrez](https://github.com/AlbertSuarez)

## License

Apache-2.0 © nmslib-viz
